A metadata plugin for ``isbnlib`` (https://pypi.python.org/pypi/isbnlib) using the service from the Servizio Bibliotecario Nazionale (Italy) (https://opac.sbn.it/) for books in Italian.

After install (pip install isbnlib-sbn) a new metadata provider (``sbn``) is available in isbnlib.

For available plugins check_ here.



.. _check: https://pypi.python.org/pypi?%3Aaction=search&term=isbnlib_&submit=search
